Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PointMutation ¶
func PointMutation(pset tree.PrimitiveSet) engine.MutationFunc[tree.Tree]
PointMutation returns a mutation function that randomly changes the function or terminal value of a node.
func SubtreeCrossover ¶
func SubtreeCrossover() engine.CrossoverFunc[tree.Tree]
SubtreeCrossover returns a crossover function for GP trees. It selects a random node in both parents and swaps the subtrees rooted at those nodes.
func SubtreeMutation ¶
func SubtreeMutation(maxDepth int, pset tree.PrimitiveSet) engine.MutationFunc[tree.Tree]
SubtreeMutation returns a mutation function that replaces a random node with a newly generated subtree.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.